"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getTimeoutFetch;

function getTimeoutFetch(fetch, timeout) {
  var timeoutFetch;

  if (fetch.polyfill) {
    timeoutFetch = function timeoutFetch(request) {
      return fetch(request, {
        timeout: timeout
      });
    };
  } else {
    timeoutFetch = function timeoutFetch(request) {
      return new Promise(function (resolve, reject) {
        var timeout = setTimeout(function () {
          reject(new TypeError('Network request timeout'));
        }, timeout);
        fetch(request).then(function (response) {
          clearTimeout(timeout);
          resolve(response);
        }).catch(function (err) {
          clearTimeout(timeout);
          reject(err);
        });
      });
    };
  }

  return timeoutFetch;
}